@@ -1,9 +1,6 @@
-# Copyright (c) 2019-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 # Note: starting with version 1.18 numpy module has `__getattr__` method which prevent
 # `pylint` to emit `no-member` message for all numpy's attributes. (see pylint's module
@@ -152,6 +149,5 @@ def numpy_core_umath_transform():
     )
 
 
-register_module_extender(
-    AstroidManager(), "numpy.core.umath", numpy_core_umath_transform
-)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "numpy.core.umath", numpy_core_umath_transform)
