@@ -1,12 +1,16 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
+
 import random
 
-from astroid import helpers
+from astroid.context import InferenceContext
 from astroid.exceptions import UseInferenceDefault
 from astroid.inference_tip import inference_tip
 from astroid.manager import AstroidManager
-from astroid.node_classes import (
+from astroid.nodes.node_classes import (
     Attribute,
     Call,
     Const,
@@ -16,6 +20,7 @@ from astroid.node_classes import (
     Set,
     Tuple,
 )
+from astroid.util import safe_infer
 
 ACCEPTED_ITERABLES_FOR_SAMPLE = (List, Set, Tuple)
 
@@ -26,7 +31,13 @@ def _clone_node_with_lineno(node, parent, lineno):
     cls = node.__class__
     other_fields = node._other_fields
     _astroid_fields = node._astroid_fields
-    init_params = {"lineno": lineno, "col_offset": node.col_offset, "parent": parent}
+    init_params = {
+        "lineno": lineno,
+        "col_offset": node.col_offset,
+        "parent": parent,
+        "end_lineno": node.end_lineno,
+        "end_col_offset": node.end_col_offset,
+    }
     postinit_params = {param: getattr(node, param) for param in _astroid_fields}
     if other_fields:
         init_params.update({param: getattr(node, param) for param in other_fields})
@@ -36,33 +47,39 @@ def _clone_node_with_lineno(node, parent, lineno):
     return new_node
 
 
-def infer_random_sample(node, context=None):
+def infer_random_sample(node, context: InferenceContext | None = None):
     if len(node.args) != 2:
         raise UseInferenceDefault
 
-    length = node.args[1]
-    if not isinstance(length, Const):
+    inferred_length = safe_infer(node.args[1], context=context)
+    if not isinstance(inferred_length, Const):
         raise UseInferenceDefault
-    if not isinstance(length.value, int):
+    if not isinstance(inferred_length.value, int):
         raise UseInferenceDefault
 
-    inferred_sequence = helpers.safe_infer(node.args[0], context=context)
+    inferred_sequence = safe_infer(node.args[0], context=context)
     if not inferred_sequence:
         raise UseInferenceDefault
 
     if not isinstance(inferred_sequence, ACCEPTED_ITERABLES_FOR_SAMPLE):
         raise UseInferenceDefault
 
-    if length.value > len(inferred_sequence.elts):
+    if inferred_length.value > len(inferred_sequence.elts):
         # In this case, this will raise a ValueError
         raise UseInferenceDefault
 
     try:
-        elts = random.sample(inferred_sequence.elts, length.value)
+        elts = random.sample(inferred_sequence.elts, inferred_length.value)
     except ValueError as exc:
         raise UseInferenceDefault from exc
 
-    new_node = List(lineno=node.lineno, col_offset=node.col_offset, parent=node.scope())
+    new_node = List(
+        lineno=node.lineno,
+        col_offset=node.col_offset,
+        parent=node.scope(),
+        end_lineno=node.end_lineno,
+        end_col_offset=node.end_col_offset,
+    )
     new_elts = [
         _clone_node_with_lineno(elt, parent=new_node, lineno=new_node.lineno)
         for elt in elts
@@ -71,7 +88,7 @@ def infer_random_sample(node, context=None):
     return iter((new_node,))
 
 
-def _looks_like_random_sample(node):
+def _looks_like_random_sample(node) -> bool:
     func = node.func
     if isinstance(func, Attribute):
         return func.attrname == "sample"
@@ -80,6 +97,7 @@ def _looks_like_random_sample(node):
     return False
 
 
-AstroidManager().register_transform(
-    Call, inference_tip(infer_random_sample), _looks_like_random_sample
-)
+def register(manager: AstroidManager) -> None:
+    manager.register_transform(
+        Call, inference_tip(infer_random_sample), _looks_like_random_sample
+    )
